==> zapp-react-native-ui-components-12.0.0-rc.88.tgz: package/Components/VideoModal/ModalAnimation/AnimatedPlayerModalWrapper.tsx <==
import React from "react";
import { Animated, ViewStyle } from "react-native";

import {
  useModalAnimationContext,
  PlayerAnimationStateEnum,
} from "@applicaster/zapp-react-native-ui-components/Components/VideoModal/ModalAnimation";
import { useDimensions } from "@applicaster/zapp-react-native-utils/reactHooks";

type Props = {
  style: ViewStyle[];
  children: React.ReactNode;
};

export const AnimatedPlayerModalWrapper = (props: Props) => {
  const {
    playerAnimationState,
    animatedValues: { lastScrollY, dragScrollY, translateYOffset },
    modalSnapPoints,
    setStartComponentsAnimation,
    lastScrollYValue,
  } = useModalAnimationContext();

  const { height: screenHeight } = useDimensions("screen", {
    deviceInfo: true,
  });

  const interpolateConfig: Animated.InterpolationConfigType = React.useMemo(
    () => ({
      inputRange: modalSnapPoints,
      outputRange: modalSnapPoints,
      extrapolate: "clamp",
    }),
    [modalSnapPoints]
  );

  let translateY;

  if (playerAnimationState === PlayerAnimationStateEnum.drag_player) {
    translateY = translateYOffset.interpolate(interpolateConfig);
  } else {
    const reverseLastScrollY = Animated.multiply(
      new Animated.Value(-1),
      lastScrollY
    );

    translateY = Animated.add(
      translateYOffset,
      Animated.add(dragScrollY, reverseLastScrollY)
    ).interpolate(interpolateConfig);
  }

  React.useEffect(() => {
    const translateYListener = translateY.addListener(({ value }) => {
      const preparedValue = Math.round(
        Math.abs(value) - lastScrollYValue.current
      );

      (playerAnimationState === PlayerAnimationStateEnum.minimize ||
        playerAnimationState === PlayerAnimationStateEnum.maximaze) &&
        setStartComponentsAnimation(
          preparedValue >= Math.round((screenHeight * 10) / 100)
        );
    });

    return () => {
      translateYListener && translateY.removeListener(translateYListener);
    };
  }, [playerAnimationState]);

  return (
    <Animated.View
      style={[props.style, { transform: [{ translateY: translateY }] }]}
    >
      {props.children}
    </Animated.View>
  );
};

==> zapp-react-native-ui-components-12.0.17.tgz: package/Components/VideoModal/ModalAnimation/AnimatedPlayerModalWrapper.tsx <==
import React from "react";
import { Animated, ViewStyle } from "react-native";

import {
  useModalAnimationContext,
  PlayerAnimationStateEnum,
} from "@applicaster/zapp-react-native-ui-components/Components/VideoModal/ModalAnimation";

type Props = {
  style: ViewStyle[];
  children: React.ReactNode;
};

export const AnimatedPlayerModalWrapper = (props: Props) => {
  const {
    playerAnimationState,
    animatedValues: { lastScrollY, dragScrollY, translateYOffset },
    modalSnapPoints,
    setStartComponentsAnimation,
  } = useModalAnimationContext();

  const interpolateConfig: Animated.InterpolationConfigType = React.useMemo(
    () => ({
      inputRange: modalSnapPoints,
      outputRange: modalSnapPoints,
      extrapolate: "clamp",
    }),
    [modalSnapPoints]
  );

  let translateY;

  if (playerAnimationState === PlayerAnimationStateEnum.drag_player) {
    translateY = translateYOffset.interpolate(interpolateConfig);
  } else {
    const reverseLastScrollY = Animated.multiply(
      new Animated.Value(-1),
      lastScrollY
    );

    translateY = Animated.add(
      translateYOffset,
      Animated.add(dragScrollY, reverseLastScrollY)
    ).interpolate(interpolateConfig);
  }

  React.useEffect(() => {
    (playerAnimationState === PlayerAnimationStateEnum.minimize ||
      playerAnimationState === PlayerAnimationStateEnum.maximize) &&
      setStartComponentsAnimation(true);
  }, [playerAnimationState]);

  return (
    <Animated.View
      style={[props.style, { transform: [{ translateY: translateY }] }]}
    >
      {props.children}
    </Animated.View>
  );
};
